@@ -3,19 +3,46 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-"""Represent the NDB Atlas structure (a minimal subset of PDB format).
+"""Represent the NDB Atlas structure (a minimal subset of PDB format) (DEPRECATED).
 
 Hetero, Crystal and Chain exist to represent the NDB Atlas structure.  Atlas
-is a minimal subset of the PDB format.  Heteo supports a 3 alphameric code.
+is a minimal subset of the PDB format.  Hetero supports a 3 alphanumeric code.
 The NDB web interface is located at http://ndbserver.rutgers.edu
+
+Bio.Crystal.Hetero substitute is Bio.PDB.Atom
+Bio.Crystal.Chain substitute is Bio.PDB.Chain
+Bio.Crystal.Crystal substitute is Bio.PDB.Structure
+
+Using Bio.PDB you can navigate the data as below::
+
+    from Bio.PDB.PDBParser import PDBParser
+    parser = PDBParser(PERMISSIVE=1)
+    # PDB NDB Only file
+    structure = parser.get_structure("001", "001_msd.pbd")
+    for model in structure:
+        print('Model ',model)
+        for chain in model:
+            print('Chain ', chain)
+            for residue in chain:
+                print('Res ', residue)
+                for atom in residue:
+                    print('Atom ', atom)
+
+Bio.Crystal is self-contained, with the main functionality covered by Bio.PDB.
 """
 
 import copy
+import warnings
 from functools import reduce
 
 from Bio._py3k import map
 from Bio._py3k import basestring
 
+from Bio import BiopythonDeprecationWarning
+warnings.warn("Bio.Crystal has been deprecated, and we intend to remove it"
+              " in a future release of Biopython. Please use Bio.PDB instead"
+              " to parse NDB files.", BiopythonDeprecationWarning)
+
 
 class CrystalError(Exception):
     """Class to manage errors."""
@@ -25,38 +52,38 @@ class CrystalError(Exception):
 
 def wrap_line(line):
     """Add end of line at character eighty, to match PDB record standard."""
-    output = ''
+    output = ""
     for i in range(0, len(line), 80):
-        output += '%s\n' % line[i: i + 80]
+        output += "%s\n" % line[i : i + 80]
     return output
 
 
 def validate_key(key):
     """Check if key is a string and has at least one character."""
     if not isinstance(key, str):
-        raise CrystalError('chain requires a string label')
+        raise CrystalError("chain requires a string label")
     if len(key) != 1:
-        raise CrystalError('chain label should contain one letter')
+        raise CrystalError("chain label should contain one letter")
 
 
 class Hetero(object):
     """Class to support the PDB hetero codes.
 
     Supports only the 3 alphanumeric code.
-    The annotation is available from http://xray.bmc.uu.se/hicup/
+    The annotation is available from http://xray.bmc.uu.se/hicup/xname.html
     """
 
     def __init__(self, data):
         """Initialize the class."""
         # Enforce string storage
         if not isinstance(data, str):
-            raise CrystalError('Hetero data must be an alphanumeric string')
+            raise CrystalError("Hetero data must be an alphanumeric string")
         if data.isalnum() == 0:
-            raise CrystalError('Hetero data must be an alphanumeric string')
+            raise CrystalError("Hetero data must be an alphanumeric string")
         if len(data) > 3:
-            raise CrystalError('Hetero data may contain up to 3 characters')
+            raise CrystalError("Hetero data may contain up to 3 characters")
         if len(data) < 1:
-            raise CrystalError('Hetero data must not be empty')
+            raise CrystalError("Hetero data must not be empty")
 
         self.data = data[:].lower()
 
@@ -80,18 +107,18 @@ class Hetero(object):
 class Chain(object):
     """Class representing a sequence of Hetero elements."""
 
-    def __init__(self, residues=''):
+    def __init__(self, residues=""):
         """Initialize the class."""
         self.data = []
         if isinstance(residues, str):
-            residues = residues.replace('*', ' ')
+            residues = residues.replace("*", " ")
             residues = residues.strip()
             elements = residues.split()
             self.data = [Hetero(x) for x in elements]
         elif isinstance(residues, list):
             for element in residues:
                 if not isinstance(element, Hetero):
-                    raise CrystalError('Text must be a string')
+                    raise CrystalError("Text must be a string")
             for residue in residues:
                 self.data.append(residue)
         elif isinstance(residues, Chain):
@@ -111,9 +138,9 @@ class Chain(object):
             raise TypeError
 
     def __str__(self):
-        output = ''
+        output = ""
         for element in self.data:
-            output = output + '%s ' % element
+            output = output + "%s " % element
         output = output.strip()
         output = wrap_line(output)
         return output
@@ -121,7 +148,9 @@ class Chain(object):
     def __eq__(self, other):
         if len(self.data) != len(other.data):
             return 0
-        ok = reduce(lambda x, y: x and y, map(lambda x, y: x == y, self.data, other.data))
+        ok = reduce(
+            lambda x, y: x and y, map(lambda x, y: x == y, self.data, other.data)
+        )
         return ok
 
     def __ne__(self, other):
@@ -238,7 +267,7 @@ class Crystal(object):
         """Initialize the class."""
         # Enforce storage
         if not isinstance(data, dict):
-            raise CrystalError('Crystal must be a dictionary')
+            raise CrystalError("Crystal must be a dictionary")
         if data is None:
             self.data = {}
         else:
@@ -261,15 +290,15 @@ class Crystal(object):
                 raise TypeError
 
     def __repr__(self):
-        output = ''
+        output = ""
         for key in sorted(self.data):
-            output += '%s : %s\n' % (key, self.data[key])
+            output += "%s : %s\n" % (key, self.data[key])
         return output
 
     def __str__(self):
-        output = ''
+        output = ""
         for key in sorted(self.data):
-            output += '%s : %s\n' % (key, self.data[key])
+            output += "%s : %s\n" % (key, self.data[key])
         return output
 
     def tostring(self):
